# Portal: Parameterized Links
The Portal provides you the possibility to add relevant deep links in the SAP LeanIX products or to external pages related to the portal content (e.g. to your help desk).
  * Global Action button
  * Resource links in the Fact Sheet detail view


The following variables are supported:
  * <factSheetId>: the ID of the currently selected Fact Sheet
  * <factSheetType>: the type of the currently selected Fact Sheet (e.g. Application)
  * <factSheetName>: the name of the currently selected Fact Sheet
  * <userId>: the ID of the current user
  * <workspaceName>: the name of the current workspace


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743b76d7a44101486f6d41ccaaad6ba_LowRes.png)
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioaa4a9cfe1d79404bab30b7efd577098e_HiRes.png)
